@@ -1,5 +1,6 @@
 from .admin_login import AdminLoginView
 from .login import OAuth2LoginView
 from .login_success import LoginSuccessView
+from .logout import LogoutView
 
-__all__ = ["OAuth2LoginView", "LoginSuccessView", "AdminLoginView"]
+__all__ = ["OAuth2LoginView", "LoginSuccessView", "AdminLoginView", "LogoutView"]
